==> u_team_core-fabric-1.20.1-5.1.4.372-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/screen/TestInventoryScreen.java <==
package info.u_team.u_team_test.test_multiloader.screen;

import info.u_team.u_team_core.gui.elements.UButton;
import info.u_team.u_team_core.gui.elements.USlider;
import info.u_team.u_team_core.screen.UContainerMenuScreen;
import info.u_team.u_team_test.test_multiloader.TestMultiLoaderReference;
import info.u_team.u_team_test.test_multiloader.menu.TestInventoryMenu;
import io.netty.buffer.Unpooled;
import net.minecraft.class_1661;
import net.minecraft.class_2540;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;

public class TestInventoryScreen extends UContainerMenuScreen<TestInventoryMenu> {
	
	private static final class_2960 BACKGROUND = new class_2960(TestMultiLoaderReference.MODID, "textures/gui/test_inventory.png");
	
	private USlider slider;
	
	public TestInventoryScreen(TestInventoryMenu menu, class_1661 playerInventory, class_2561 title) {
		super(menu, playerInventory, title, BACKGROUND, 176, 173);
	}
	
	@Override
	protected void method_25426() {
		super.method_25426();
		method_37063(new UButton(field_2776 + field_2792 / 2 - 25, field_2800 + 3, 50, 15, class_2561.method_43470("Add 100"), button -> {
			field_2797.getValueMessage().triggerMessage();
		}));
		
		slider = method_37063(new USlider(field_2776 + 7, field_2800 + 19, 162, 20, class_2561.method_43470("Cooldown: "), class_2561.method_43470(" Ticks"), 0, 100, field_2797.getBlockEntity().getCooldown(), false, true, slider -> {
			field_2797.getCooldownMessage().triggerMessage(() -> new class_2540(Unpooled.copyShort(slider.getValueInt())));
		}));
	}
	
	@Override
	public void method_37432() {
		super.method_37432();
		if ((!method_25397() || !slider.method_25367()) && field_22787.field_1687.method_8510() % 20 == 0) {
			slider.method_25347(field_2797.getBlockEntity().getCooldown());
		}
	}
	
	@Override
	protected void method_2388(class_332 guiGrapics, int mouseX, int mouseY) {
		super.method_2388(guiGrapics, mouseX, mouseY);
		guiGrapics.method_51433(field_22793, Integer.toString(field_2797.getBlockEntity().getValue()), field_2792 / 2 + 32, 6, 0x404040, false);
	}
	
}

==> u_team_core-fabric-1.21.1-5.6.2.374-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/screen/TestInventoryScreen.java <==
package info.u_team.u_team_test.test_multiloader.screen;

import info.u_team.u_team_core.gui.elements.UButton;
import info.u_team.u_team_core.gui.elements.USlider;
import info.u_team.u_team_core.screen.UContainerMenuScreen;
import info.u_team.u_team_test.test_multiloader.TestMultiLoaderReference;
import info.u_team.u_team_test.test_multiloader.menu.TestInventoryMenu;
import io.netty.buffer.Unpooled;
import net.minecraft.class_1661;
import net.minecraft.class_2540;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;

public class TestInventoryScreen extends UContainerMenuScreen<TestInventoryMenu> {
	
	private static final class_2960 BACKGROUND = class_2960.method_60655(TestMultiLoaderReference.MODID, "textures/gui/test_inventory.png");
	
	private USlider slider;
	
	public TestInventoryScreen(TestInventoryMenu menu, class_1661 playerInventory, class_2561 title) {
		super(menu, playerInventory, title, BACKGROUND, 176, 173);
	}
	
	@Override
	protected void method_25426() {
		super.method_25426();
		method_37063(new UButton(field_2776 + field_2792 / 2 - 25, field_2800 + 3, 50, 15, class_2561.method_43470("Add 100"), button -> {
			field_2797.getValueMessage().triggerMessage();
		}));
		
		slider = method_37063(new USlider(field_2776 + 7, field_2800 + 19, 162, 20, class_2561.method_43470("Cooldown: "), class_2561.method_43470(" Ticks"), 0, 100, field_2797.getBlockEntity().getCooldown(), false, true, slider -> {
			field_2797.getCooldownMessage().triggerMessage(() -> new class_2540(Unpooled.copyShort(slider.getValueInt())));
		}));
	}
	
	@Override
	public void method_37432() {
		super.method_37432();
		if ((!method_25397() || !slider.method_25367()) && field_22787.field_1687.method_8510() % 20 == 0) {
			slider.method_25347(field_2797.getBlockEntity().getCooldown());
		}
	}
	
	@Override
	protected void method_2388(class_332 guiGrapics, int mouseX, int mouseY) {
		super.method_2388(guiGrapics, mouseX, mouseY);
		guiGrapics.method_51433(field_22793, Integer.toString(field_2797.getBlockEntity().getValue()), field_2792 / 2 + 32, 6, 0x404040, false);
	}
	
}
